/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.server;

import org.apache.accumulo.core.cli.ConfigOpts;

import com.beust.jcommander.Parameter;

public class ServerOpts extends ConfigOpts {

  public static final String BIND_ALL_ADDRESSES = "0.0.0.0";

  @Parameter(names = {"-a", "--address"},
      description = "address to bind to (deprecated, use `-o rpc.bind.addr=<address>` instead)")
  private String address = null;

  public String getAddress() {
    if (address != null) {
      return address;
    }
    return BIND_ALL_ADDRESSES;
  }
}
